/*  Prototype JavaScript framework, version 1.5.0
 *  (c) 2005-2007 Sam Stephenson
 *
 *  Prototype is freely distributable under the terms of an MIT-style license.
 *  For details, see the Prototype web site: http://prototype.conio.net/
 *
/*--------------------------------------------------------------------------*/

/// NOTE This version of Prototype has been stripped down to just what was needed
/// for this application
/// -----------------------------------------------------------------------------

// Declare the prototype "class"
var Prototype = {
  Version: '1.5.0',
  BrowserFeatures: {
    XPath: !!document.evaluate
  },
  K: function(x) { return x }
}

// A function that extends the functionality of an object.
// This takes a destination object and a "chunk of code" to
// tie to it.
Object.extend = function(destination, source) {
   // For each of the properties in the source 
   for (var property in source) {
      // Assign that property to the destination object.
      destination[property] = source[property];
   }
   return destination;
}

// A regular expression that matches the html script tag syntax
// The double \\ below is because this file is being run through the interpreter
// and that is an escape char and it will get stripped if you don't dbl it.
var ScriptFragment = '(?:<script.*?>)((\\n|\\r|.)*?)(?:<\\/script>)';

// Here the Array object is being extended
Object.extend(Array.prototype, {
   // An "_each" function is being created that takes an iterator
  _each: function(iterator) {
    for (var i = 0, length = this.length; i < length; i++)
      iterator(this[i]);
  }
});

var $break = new Object();
var $continue = new Object();

// Create an enumerable class
var Enumerable = {
   // The each property
   each: function(iterator) {
      var index = 0;
      try {
         this._each(function(value) {
         try {
            iterator(value, index++);
         } catch (e) {
            if (e != $continue) throw e;
         }
         });
      } catch (e) {
         if (e != $break) throw e;
      }
      return this;
   },
   // The collect property
   collect: function(iterator) {
      var results = [];
      this.each(function(value, index) {
         results.push((iterator || Prototype.K)(value, index));
      });
      return results;
   }
   }

// Extend the object class to use a map that uses the collect property of enumerable.
Object.extend(Enumerable, {
  map:     Enumerable.collect
});

// Modifies the array class.
var $A = Array.from = function(iterable) {
  if (!iterable) return [];
  if (iterable.toArray) {
    return iterable.toArray();
  } else {
    var results = [];
    for (var i = 0, length = iterable.length; i < length; i++)
      results.push(iterable[i]);
    return results;
  }
}

// Adds the Enumerable type to the Array class.
Object.extend(Array.prototype, Enumerable);

//Add the extract scripts functionality to the String class
Object.extend(String.prototype, {
    extractScripts: function() {
    var matchAll = new RegExp(ScriptFragment, 'img');
    var matchOne = new RegExp(ScriptFragment, 'im');
    return (this.match(matchAll) || []).map(function(scriptTag) {
         return (scriptTag.match(matchOne) || ['', ''])[1];
    });
  }
});

// Fixes the closure problem with JS
Function.prototype.bind = function(obj)
{
   var method = this;
   var args = [];
   for (var n = 1; n < arguments.length; n++) {
      args.push(arguments[n]);
   }

   var temp = function() {
      if(args.length !=0) {
         return method.apply(obj, args);
      } else {
         return method.apply(obj, arguments);
      }
   };

   return temp;
}
